SanitizerOptions class
Options used to sanitize log payloads.
- Annotations
-
- @immutable
Constructors
- SanitizerOptions({bool skipSanitization = false, Sanitizer? sanitizer})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sanitizer → Sanitizer?
-
final
- skipSanitization → bool
-
final
Methods
-
copyWith(
{bool? skipSanitization, Sanitizer? sanitizer}) → SanitizerOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited