LoggerAdapterConfig class
Base configuration for any adapter.
- Implementers
- Annotations
-
- @immutable
Constructors
Properties
- enabled → bool
-
Whether the adapter should process logs.
final
-
extras
→ Map<
String, Object?> -
Additional adapter-specific configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → LogLevel?
-
Minimum severity threshold that should be processed.
final
Methods
-
merge(
{bool? enabled, LogLevel? severity, Map< String, Object?> ? extras}) → LoggerAdapterConfig -
Creates a new config merging the current extras with
updates. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited